@@ -1,7 +1,7 @@
 package Data::Sah::Resolve;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-04-16'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ sub _resolve {
     my $schmod = "Sah::Schema::$type";
     (my $schmod_pm = "$schmod.pm") =~ s!::!/!g;
     eval { require $schmod_pm; 1 };
-    die "Not a known type/schema name '$type'" if $@;
+    die "Not a known type/schema name '$type' ($@)" if $@;
     no strict 'refs';
     my $sch2 = ${"$schmod\::schema"};
     die "BUG: Schema module $schmod doesn't contain \$schema" unless $sch2;
@@ -114,7 +114,7 @@ Data::Sah::Resolve - Resolve Sah schema
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2016-07-26.
+This document describes version 0.005 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2017-04-16.
 
 =head1 SYNOPSIS
 
@@ -193,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
